/*
** MorphOS wrappers to use same UI when possible.
** mos_EZEasy 2001-2003 Jacek Piszczek, originaly part of ReqAttack.
** $Id: mos_wrappers.c,v 1.2 2005/03/31 18:33:06 piru Exp $
*/

#include <exec/types.h>
#include <proto/exec.h>
#include <proto/reqtools.h>
#include <proto/intuition.h>
#include <proto/utility.h>
#include <exec/libraries.h>
#include <exec/memory.h>
#include <libraries/reqtools.h>
#include <aros/libcall.h>

#include "reqtools_intern.h"
#include "general.h"
#include "globalvars.h"

#ifdef USEWRAPPERS

ULONG mos_EZEasy(char *bodyfmt,char *gadfmt,struct rtReqInfo *reqinfo,APTR argarray,struct TagItem *taglist,struct IntReqToolsBase *IntReqToolsBase)
{
	ULONG rc,idcmp;
	struct EasyStruct es;
	struct Window *win=NULL;
	struct Screen *sc;
	UBYTE *gadformat=NULL;
	UBYTE underscore;
	BOOL closew=FALSE;

	if (gadfmt == 0) return -3; //kein gadgets not allowed ;)
	if (GetTagData(RT_ReqHandler,0,taglist) != 0) return -3; //asynch reqs not supported :(
	if (GetTagData(RT_ShareIDCMP,0,taglist) != 0 && GetTagData(RT_IntuiMsgFunc,0,taglist) != 0) return -3;

	rc = GetTagData(RT_PubScrName,0,taglist);
	if (rc)
	{
		sc = LockPubScreen((char*)rc);
		if (sc)
		{
			win = OpenWindowTags(0,WA_CustomScreen,(ULONG)sc,WA_Left,0,WA_Top,0,WA_Width,1,WA_Height,1,WA_Flags,WFLG_BACKDROP|WFLG_BORDERLESS,TAG_DONE);
			closew=TRUE;
			UnlockPubScreen(NULL,sc);
		}
	}

	if (!(win))
	{
		sc = (struct Screen *)GetTagData(RT_Screen,0,taglist);
		if (sc)
		{
			win = OpenWindowTags(0,WA_CustomScreen,(ULONG)sc,WA_Left,0,WA_Top,0,WA_Width,1,WA_Height,1,WA_Flags,WFLG_BACKDROP|WFLG_BORDERLESS,TAG_DONE);
			closew=TRUE;
		}
	}

	if(!(win)) win = (struct Window *)GetTagData(RT_Window,0,taglist);

	if (!(win)) //if no window -> try pr_WindowPtr
	{
		struct Process *proc;

		proc = (struct Process *)FindTask(0);
		if (proc->pr_Task.tc_Node.ln_Type == NT_PROCESS)
		{
			win = proc->pr_WindowPtr;
		}
	}

	underscore = GetTagData(RT_Underscore,0,taglist);
	if (underscore && underscore != '|')
	{
		gadformat = AllocVec(strlen(gadfmt) + 1,MEMF_PUBLIC);
		if (gadformat)
		{
			UBYTE *dst;
			UBYTE ch;
			BOOL skipped = FALSE;

			dst = gadformat;
			while ((ch = *gadfmt++))
			{
				if (ch == underscore && !skipped)
				{
					skipped = TRUE;
					continue;
				}

				if (ch == '|')
				{
					skipped = FALSE;
				}

				*dst++ = ch;
			}
			*dst = '\0';

			gadfmt = gadformat;
		}
	}

	idcmp = GetTagData(RT_IDCMPFlags,0,taglist);

	es.es_StructSize = sizeof(struct EasyStruct);
	es.es_Flags = 0;
	es.es_Title = (UBYTE *)GetTagData(RTEZ_ReqTitle,0,taglist);
	es.es_TextFormat = (UBYTE *)bodyfmt;
	es.es_GadgetFormat = (UBYTE *)gadfmt;

	rc = EasyRequestArgs(win, &es, idcmp ? &idcmp : NULL, argarray);

	if (gadformat) FreeVec(gadformat);
	if (closew && win) CloseWindow(win);

	return rc;
}

#endif
